TOW.SettingsPanel = {

	init: function() {
		this.initElements();
		this.bindEvents();
		this.loadSettings();
	},

	initElements: function() {
		this.$compilation = $('#compilation');
		this.$compilationsCount = $('#compilationsCount');
		this.$fontSizeSlider = $('#fontSizeSlider');
		this.$inputFontSize = $('#inputFontSize');
		this.$editorTheme = $('#editorTheme');
	},

	bindEvents: function() {
		var self = this;

		// Zobrazi okno s nastavenim
		$('#settings').click(function() {
			$('#sideMenuSettings').toggle('slide', {direction: 'right'}, 'fast');
		});

		// Zmena nastaveni font size
		this.$inputFontSize.change(function() {
			editor.setFontSize(parseInt(self.$inputFontSize.val()));
		});

		// nastavi select jako jQueryUI selectmenu
		$('.selectmenu').selectmenu({
			width: 'auto'
		});

		// nastavi barevne schema editoru
		$('#editorTheme').on('selectmenuchange', function(e, ui) {
			editor.setTheme('ace/theme/' + ui.item.value);
		});

		// nastavi typ prekladu
		this.$compilation.on('selectmenuchange', function(e, ui) {
			var compilation = $(this).find('option:selected').val();
			self.setCompileFormInput('preklad', compilation);
		});

		// nastavi pocet prekladu jako jQueryUI buttonset
		this.$compilationsCount.buttonset().change(function(e) {
			e.preventDefault();
			var compilationsCount = $(this).find(':radio:checked').val();
			self.setCompileFormInput('pruchod', compilationsCount);
		});

		// nastavi velikost pisma editoru pomoci jQueryUI slider
		this.slider = this.$fontSizeSlider.slider({
			value: 14,
			min: 8,
			max: 40,
			step: 2,
			slide: function(e, ui) {
				self.$inputFontSize.val(ui.value + ' px');
				editor.setFontSize(parseInt(ui.value));
			}
		});
		this.$inputFontSize.val(this.$fontSizeSlider.slider('value') + ' px');

		// ulozeni nastaveni
		$('#btnSaveSettings').click(function(e) {
			e.preventDefault();
			var compilation = self.$compilation.find('option:selected').val();
			var compilationsCount = self.$compilationsCount.find(':radio:checked').val();
			var fontSize = self.$fontSizeSlider.slider('value') + 'px';
			var editorContent = editor.getValue();
			var theme = self.$editorTheme.find('option:selected').val();
			
			$.post('nastav.pl', {
				save: true,
				zobraz_text: 1,
				zobraz_vystup: 1,
				zobraz_preklad: 1,
				zobraz_pruchod: 1,
				komprimace: 0,
				zobraz_komprimaci: 1,
				zobraz_panel: 1,
				zobraz_syntax: 1,
				vytvor_verze: 0,
				obsah: '\\documentclass{article} \\n\\usepackage{xltxtra,polyglossia} \\n\\setdefaultlanguage{czech} \\n\\begin{document} \\n\\n\\n\\n\\end{document}',
				vystup: 'PDF',
				preklad: compilation,
				pruchod: compilationsCount,
				pismo_vel: fontSize,
				pismo_typ: 'normální',
				schema: theme,
				editor: '100%'
			}, function(data) {
				$('#flashMessages').flashMessage({
					text: 'Nastavení bylo úspěšně uloženo.',
					className: 'success'
				});
			});
		});
		
	},

	loadSettings: function() {
		var self = this;
		if (isUserAutheticated()) {
			$.post('nastav.pl', function(data) {
				var arr = data.split(';');
				var settings = {};
				for (var i=0; i<arr.length; i++) {
					var tmpArr = arr[i].split('=');
					settings[tmpArr[0]] = tmpArr[1];
				}
				//editor.setValue(settings.editor, -1);
				//editor.focus();
				self.setCompilationSettings(settings.preklad);
				self.setCompilationsCountSettings(settings.pruchod);
				self.setFontSizeSettings(settings.pismo_vel);
				self.setEditorTheme(settings.schema);
			});
		}
	},

	setCompilationSettings: function(value) {
		this.$compilation.val(value).selectmenu('refresh');
		this.setCompileFormInput('preklad', value);
	},

	setCompilationsCountSettings: function(value) {
		this.$compilationsCount.find('#compCount' + value).prop('checked', true).button('refresh');
		this.setCompileFormInput('pruchod', value);
	},

	setFontSizeSettings: function(fontSize) {
		fontSize = fontSize.replace(/\D/g, ''); // remove 'px' unit
		this.$fontSizeSlider.slider('value', fontSize);
		this.$inputFontSize.val(this.$fontSizeSlider.slider('value') + ' px');
		editor.setFontSize(parseInt(this.$inputFontSize.val()));
	},

	setEditorTheme: function(theme) {
		if (theme != null) {
			this.$editorTheme.val(theme).selectmenu('refresh');
			editor.setTheme('ace/theme/' + theme);
		}
	},

	setCompileFormInput: function(name, value) {
		$('#formular select[name="' + name + '"] option')
			.removeAttr('selected')
			.filter('[value="' + value + '"]')
			.prop('selected', true);
	}

};

$(function() {
	TOW.SettingsPanel.init();
});
