TOW.ToolsPanel = {

	init: function() {
		this.initElements();
		this.bindEvents();
	},

	initElements: function() {
		var self = this;
		this.$main = $('#main');
		this.$imgModal = $('#insertImageModal');
		this.$spellCheckModal = $('#spellCheckModal');
		this.$insertListModal = $('#insertListModal');
		this.$insertTableModal = $('#insertTableModal');
		this.$currCorrectionText = $('#currCorrectionText');
		this.$suggestionsContainer = $('#suggestionsContainer');
		this.$btnProcessCorrection = $('#btnProcessCorrection');
		this.$btnAddToDictionary = $('#btnAddToDictionary');
		this.$btnIgnoreWord = $('#btnIgnoreWord');
		this.$btnNextWord = $('#btnNextWord');
		this.$btnPreviousWord = $('#btnPreviousWord');
		this.$btnOrderedList = $('#btnOrderedList');
		this.$btnUnorderedList = $('#btnUnorderedList');
		this.misspelledWords = [];
		this.currentSpellCheckMarker = null;
		this.spellCheckHighlightMarker = null;
		this.ignoredWords = [];
		this.currentMarkerPosition = 1;

		// nacteni externi sablony
		$.get('js/templates/tools-panel.hbs', function(data) {
			self.$main.append(data);
			var tpl = Handlebars.compile($('#image-modal-template').html());
			self.$imgModal.find('.modal-body').html(tpl);
		});

		// enable draggable modal
		this.$spellCheckModal.draggable({
			handle: '.modal-header',
			cursor: 'move'
		});

		this.$insertTableModal.draggable({
			handle: '.modal-header',
			cursor: 'move'
		});

		// hide Save button when not authenticated
		if (!isUserAutheticated()) {
			$("#btnSave").hide();
		}
	},

	bindEvents: function() {
		var self = this;

		$('#btnSave').click(function() {
			self.saveFile();
			editor.focus();
		});

		$('#btnItalic').click(function() {
			insertMacro('textit');
		});

		$('#btnBold').click(function() {
			insertMacro('textbf');
		});

		$('#btnSmallCaps').click(function() {
			insertMacro('textsc');
		});

		$('#btnTypewriter').click(function() {
			insertMacro('texttt');
		});

		$('#btnUndo').click(function() {
			editor.undo();
			editor.focus();
		});

		$('#btnRedo').click(function() {
			editor.redo();
			editor.focus();
		});

		$('#btnSpaces').click(function() {
			self.insertTilde();
		});

		$('#btnTables').click(function() {
			/*editor.insert('\\begin{tabular}{ccc}');
			editor.insert('\n& \\\\');
			editor.insert('\n\\end{tabular}');
			editor.focus();*/
			self.$insertTableModal.find('.modal-body').html(self.getTableModalHtml());
			self.$insertTableModal.toggle('slide', {direction: 'up'}, 'fast');
			// inicializace colormixeru
			tablemcoli();
			// skryje tlacitko vlozit a zobrazi tlacitko dalsi
			$('#btnNextTableModal').show();
			$('#btnInsertTableModal').hide();
		});

		$('#btnLists').click(function() {
			self.$insertListModal.toggle('slide', {direction: 'up'}, 'fast');
		});

		$('#btnImages').click(function() {
			if (isUserAutheticated()) {
				self.initHelpIcons();
				self.$imgModal.toggle('slide', {direction: 'up'}, 'fast');
			} else {
				insertMacro('includegraphics');
			}
		});

		$('#btnSpellCheck').click(function() {
			self.runSpellCheck();
		});

		$('#btnSearch').click(function() {
			editor.execCommand("replace");
		});

		spellCheckEvents: {
			// zavrit modal
			this.$main.on('click', '#btnCloseSpellCheckModal', this.closeSpellCheckModal.bind(this));

			// nahradit slovo
			this.$btnProcessCorrection.click(function() {
				// vzit value v currCorrectionText
				var newText = self.$currCorrectionText.val();
				// zjistit range current markeru a provest replace slova v editoru
				editor.session.replace(self.currentSpellCheckMarker.range, newText);
				// aktualizace pozice markeru
				self.updateCurrentMarkerPosition();
				// update markers
				self.runSpellCheck();
			});

			// nahradit slovo - double click na option
			this.$main.on('dblclick', '#suggestionsList option', function() {
				var newText = self.$currCorrectionText.val();
				editor.session.replace(self.currentSpellCheckMarker.range, newText);
				// aktualizace pozice markeru
				self.updateCurrentMarkerPosition();
				self.runSpellCheck();
			});

			// nastavit text opravy po kliknuti na navrhovanou moznost
			this.$main.on('change', '#suggestionsList', function() {
				var suggest = $('#suggestionsList').val();
				if (suggest !== '') {
					self.$currCorrectionText.val(suggest);
				}
			});

			// pridat slovo do slovniku
			this.$btnAddToDictionary.click(function() {
				var word = self.getWordByRange(self.currentSpellCheckMarker.range);
				$.post('pravopis.pl', {termin: encodeURIComponent(word)}, function(data) {
					$('#flashMessages').flashMessage({
						text: 'Slovo "' + word + '" bylo úspěšně přidáno do slovníku.',
						className: 'success'
					});
					self.runSpellCheck();
				});
			});

			// ignorovat slovo
			this.$btnIgnoreWord.click(function() {
				// add word to ignored list
				var word = self.getWordByRange(self.currentSpellCheckMarker.range);
				self.ignoredWords.push(word);

				// remove markers
				editor.session.removeMarker(self.currentSpellCheckMarker.id);
				self.removeSpellCheckHighlightMarker();

				// aktualizace pozice markeru
				self.updateCurrentMarkerPosition();

				self.runSpellCheck();
			});

			// dalsi slovo
			this.$btnNextWord.click(function() {
				if (self.misspelledWords.length < 2) return;

				self.removeSpellCheckHighlightMarker();
				var markers = self.getSpellCheckMarkers();
				var previous = null;
				var nextMarker = null;
				$.each(markers, function(key, marker) {
					if (previous === self.currentSpellCheckMarker) {
						nextMarker = marker;
						return false;
					}
					previous = marker;
				});

				// naslednika posledniho prvku nastavime na prvni marker
				if (nextMarker === null) {
					nextMarker = markers[0];
				}

				self.currentSpellCheckMarker = nextMarker;
				var word = self.getWordByRange(self.currentSpellCheckMarker.range);

				self.$currCorrectionText.val(word);
				self.setSuggestions(word);
				// scroll to line
				editor.scrollToLine(self.currentSpellCheckMarker.range.start.row, true, true, function () {});
				// zvyraznit aktualni slovo
				var markerId = editor.session.addMarker(self.currentSpellCheckMarker.range, "current-misspelled-word", "text");
				self.spellCheckHighlightMarker = markerId;
				// aktualizace pozice markeru
				self.updateCurrentMarkerPosition();
			});

			// predchozi slovo
			this.$btnPreviousWord.click(function() {
				if (self.misspelledWords.length < 2) return;

				self.removeSpellCheckHighlightMarker();
				var markers = self.getSpellCheckMarkers();
				markers.reverse();
				var previous = null;
				var nextMarker = null;
				$.each(markers, function(key, marker) {
					if (previous === self.currentSpellCheckMarker) {
						nextMarker = marker;
						return false;
					}
					previous = marker;
				});

				// naslednika posledniho prvku nastavime na prvni marker
				if (nextMarker === null) {
					nextMarker = markers[0];
				}

				self.currentSpellCheckMarker = nextMarker;
				var word = self.getWordByRange(self.currentSpellCheckMarker.range);

				self.$currCorrectionText.val(word);
				self.setSuggestions(word);
				// scroll to line
				editor.scrollToLine(self.currentSpellCheckMarker.range.start.row, true, true, function () {});
				// zvyraznit aktualni slovo
				var markerId = editor.session.addMarker(self.currentSpellCheckMarker.range, "current-misspelled-word", "text");
				self.spellCheckHighlightMarker = markerId;
				// aktualizace pozice markeru
				self.updateCurrentMarkerPosition();
			});
		}

		imgModalEvents: {
			// zobrazit/skryt vlastnosti
			this.$main.on('click', '#toggleImageProperties', function() {
				var $props = self.$main.find('#imageProperties');
				$props.toggle('blind', 'fast');
			});

			// zobrazit/skryt figure
			this.$main.on('change', '#enableImageFigure, #disableImageFigure', function() {
				var $fig = self.$main.find('#imageFigure');
				if ($(this).val() === 'yes') {
					$fig.show('blind', 'fast');
				} else {
					$fig.hide('blind', 'fast');
				}
			});

			// zavrit modal
			this.$main.on('click', '#btnCloseImageModal', function() {
				self.$imgModal.toggle('slide', {direction: 'up'}, 'fast');
			});

			// nahrat obrazek po vybrani souboru
			this.$main.on('change', '#imageUpload input[name=filename]', this.imageUpload.bind(this));

			// vlozit obrazek
			this.$main.on('click', '#btnInsertImage', this.insertImage.bind(this));
		}

		listModalEvents: {
			this.$btnOrderedList.click(function () {
				editor.insert('\\begin{enumerate}');
				editor.insert('\n\\item');
				editor.insert('\n\\end{enumerate}');
				editor.focus();
				self.$insertListModal.toggle('slide', {direction: 'up'}, 'fast');
			});

			this.$btnUnorderedList.click(function () {
				editor.insert('\\begin{itemize}');
				editor.insert('\n\\item');
				editor.insert('\n\\end{itemize}');
				editor.focus();
				self.$insertListModal.toggle('slide', {direction: 'up'}, 'fast');
			});

			$('#btnCloseListModal').click(function () {
				self.$insertListModal.toggle('slide', {direction: 'up'}, 'fast');
			});
		}

		tableModalEvents: {
			$('#btnCloseTableModal').click(function () {
				self.$insertTableModal.toggle('slide', {direction: 'up'}, 'fast');
			});
		}
	},


	// Spell check functions

	runSpellCheck: function() {
		var self = this;
		this.removeSpellCheckMarkers();
		this.removeSpellCheckHighlightMarker();
		this.misspelledWords = [];

		$.post('pravopis.pl', {spell: true, pole: editor.getValue()}, function(data) {
			if (data !== '') {
				var misspelledWords = $.trim(data).split(' ');
				var Search = ace.require('ace/search').Search;
				var Range = ace.require("ace/range").Range;
				var i = 1;

				$.each(misspelledWords, function(key, val) {
					// pokud je slovo v ignored words, tak jej nezvyraznovat (= skip loop)
					if ($.inArray(val, self.ignoredWords) !== -1) return true;

					var search = new Search().set({needle: val});
					var ranges = search.findAll(editor.getSession());
					var markerId = null;
					$.each(ranges, function(key, range) {
						if (!self.markerExists(range)) {
							markerId = editor.session.addMarker(range, "misspelled-word", "text");
							return false;
						}
					});
					// ulozi se marker podle pozice (defaultne prvni)
					if (i === self.currentMarkerPosition) {
						self.currentSpellCheckMarker = self.getSpellCheckMarkerById(markerId);
					}
					// ulozi se slovo
					self.misspelledWords.push(val);
					i++;
				});

				if (self.misspelledWords.length > 0) {
					// zobrazit modal
					if (!self.$spellCheckModal.is(':visible')) {
						self.$spellCheckModal.toggle('slide', {direction: 'up'}, 'fast');
					}

					var firstMisspelled = self.misspelledWords[0];
					self.$currCorrectionText.val(firstMisspelled);
					self.setSuggestions(firstMisspelled);
					// scroll to line
					editor.scrollToLine(self.currentSpellCheckMarker.range.start.row, true, true, function () {});
					// zvyraznit aktualni slovo
					var markerId = editor.session.addMarker(self.currentSpellCheckMarker.range, "current-misspelled-word", "text");
					self.spellCheckHighlightMarker = markerId;
				} else {
					if (self.$spellCheckModal.is(':visible')) {
						self.closeSpellCheckModal();
					}
					$('#flashMessages').flashMessage({
						text: 'Nebyl nalezen žádný překlep.',
						className: 'info'
					});
				}

			} else {
				if (self.$spellCheckModal.is(':visible')) {
					self.closeSpellCheckModal();
				}
				$('#flashMessages').flashMessage({
					text: 'Nebyl nalezen žádný překlep.',
					className: 'info'
				});
			}
		});
	},

	closeSpellCheckModal: function() {
		this.removeSpellCheckMarkers();
		this.removeSpellCheckHighlightMarker();
		this.$spellCheckModal.toggle('slide', {direction: 'up'}, 'fast');
	},

	setSuggestions: function(misspelledWord) {
		var self = this;

		$.post('pravopis.pl', {preklep: encodeURIComponent(misspelledWord)}, function(data) {
			var html = '<select id="suggestionsList" size="10">';
			if (data !== '') {
				html += data;
			}
			html += '</select>';
			self.$suggestionsContainer.html(html);
		});
	},

	saveFile: function() {
		if (!isFileOpen()) {
			// Schovej sablony pokud jsou zobrazeny
			if ($( "#templatesList" ).is( ":visible" )) {
        		changeTemplateIconText();
            	$( "#templatesList" ).toggle( "slide", "left", "fast" );
        	}
			readFiles("");
			initFileMenu("save");
    		//Zobrazit spravce souboru a jeho kontextovou nabidku
    		$( "#sideMenuFiles" ).toggle( "slide", "left", "fast");
    		$( "#fileManager" ).toggle( "slide", "left", "fast", setWidthSideContent);
			$( "#file_name" ).focus();
		} else {
			// Pokud soubor je jiz ulozen a tedy nacten v editoru, pak ho jen uloz
			var fileName = $('#openFile').val();
			var path = $('#openFileDir').val();
			// Priprava cesty k ulozeni souboru
			$("#fullPathSave").val(path + fileName);
			// Ziskani instance editoru a ulozeni jeho obsahu do textarea
			var editor = ace.edit("codeEdit");
			var content = editor.getSession().getValue();
			$("#pole").val(content);
			// Serializace textarea a plne cesty k ukladanemu souboru
			var serializedFormFields = $("#pole, #fullPathSave").serialize();

			$.post("index.pl", serializedFormFields, function(data){
				// Commit souboru v pripade, ze ma uzivatel zapnute verzovani
				if(isVersion)
					commitSVN(file_nm, dir_nm);

				$("#fullPathSave").val("");
				// Zobrazeni zpravy o uspesnem ulozeni a jeji nasledne skryti
				$('#flashMessages').flashMessage({
					text: TranslVar[470],
					className: 'success'
				});

				// Spusteni save eventu
				$(document).trigger('fileSaved');
			});
		}
	},

	getSpellCheckMarkers: function() {
		var markers = editor.session.getMarkers();
		var spellCheckMarkers = [];
		$.each(markers, function(i, data) {
			if (data.clazz === 'misspelled-word') {
				spellCheckMarkers.push(data);
			}
		});
		return spellCheckMarkers;
	},

	getSpellCheckMarkerById: function(id) {
		var marker = null;
		var markers = this.getSpellCheckMarkers();
		$.each(markers, function(i, data) {
			if (data.id === id) {
				marker = this;
				return false;
			}
		});
		return marker;
	},

	removeSpellCheckMarkers: function() {
		var markers = this.getSpellCheckMarkers();
		$.each(markers, function(i, data) {
			editor.session.removeMarker(data.id);
		});
	},

	removeSpellCheckHighlightMarker: function() {
		editor.session.removeMarker(this.spellCheckHighlightMarker);
	},

	getWordByRange: function(range) {
		return editor.session.getTextRange(range);
	},

	getMarkerPosition: function(marker) {
		var range = marker.range;
		var markers = this.getSpellCheckMarkers();
		var i = 1;
		$.each(markers, function(key, data) {
			var mrange = data.range;
			// TODO: better way of object compare (use Lodash?)
			if (range.start.column === mrange.start.column && range.start.row === mrange.start.row && range.end.column === mrange.end.column && range.end.row === mrange.end.row) {
				return false;
			}
			i++;
		});
		return i;
	},

	updateCurrentMarkerPosition: function() {
		var position = this.getMarkerPosition(this.currentSpellCheckMarker);
		var markersCount = this.getSpellCheckMarkers().length;
		if (position >= markersCount) {
			this.currentMarkerPosition = 1;
		} else {
			this.currentMarkerPosition = position;
		}
	},

	markerExists: function(range) {
		var result = false;
		var markers = this.getSpellCheckMarkers();
		$.each(markers, function(key, marker) {
			var mrange = marker.range;
			if (range.start.column === mrange.start.column && range.start.row === mrange.start.row && range.end.column === mrange.end.column && range.end.row === mrange.end.row) {
				result = true;
				return false;
			}
		});
		return result;
	},

	insertTilde: function() {
		// Zameni v kodu obycejnou mezeru po jednopismennych predlozkach ci spojkach za pevnou ('~').
		var cursor = editor.getCursorPosition();
		var text = editor.getValue();
		// kvůli nefunkčnosti \g opakujeme nahrazení 2x, abychom odchytili např. i "A v lese". Nezlomitelnou mezeru vkladame i kdyz je spojka pred Enterem (jen jednim)
		text = text.replace(/([^a-zěščřžýáíéóúůďťň][aoiszvku])( +|\s)/gi,"$1~");
		text = text.replace(/([^a-zěščřžýáíéóúůďťň][aoiszvku])( +|\s)/gi,"$1~");
		editor.setValue(text, -1);
		editor.selection.moveCursorToPosition(cursor);
		editor.focus();
	},

	imageUpload: function() {
		var filename = $("#imageUpload input[name=filename]").val();
		filename = filename.toString();

		// odstraneni retezce C:\fakepath\ ze jmena souboru na Chrome, IE a Safari
		if (filename.indexOf("C:\\fakepath\\") != -1)
			filename = filename.substring(filename.lastIndexOf("\\") + 1, filename.length);

		// Generovani nahodneho cisla pro nazev a id iframe, pro upload souboru
		var file = 'f' + Math.floor(Math.random() * 99999);

		// Nastaveni cesty k adresari, kam se ma soubor nahrat
		$("#imageUpload input[name=path]").val("");

		$("#imageUploadForm").attr("action", "sprava_souboru.pl");
        $("#imageUploadForm").attr("method", "post");
    	$("#imageUploadForm").attr("enctype", "multipart/form-data");
		$("#imageUploadForm").attr("target", file);


		if (confirm(TranslVar[495] + ": " + filename)) {
			$("#imageUpload").append("<iframe class='file-iframe' style=\"display:none\" id=\""+file+"\" name=\""+file+"\" onload=\"imageUploaded(\'"+file+"\')\"></iframe>");
			// Zobrazeni informativni zpravy o nahravani
			$(".flash-message").html("<img src=\"file/loading_grey.gif\" /> " + TranslVar[425]);
			$(".flash-message").removeClass("hidden");
			$('#sanitizedFilename').text(filename);
			$("#imageUploadForm").submit();
		}
	},

	initHelpIcons: function() {
		$('.help-icon').tooltipster({
			iconDesktop: true,
			iconTouch: true,
			icon: '?',
			content: 'Načítání...',
			contentAsHTML: true,
			maxWidth: 300,
		    functionBefore: function(origin, continueTooltip) {
		    	var url = ($(this).attr('href'));

		        // we'll make this function asynchronous and allow the tooltip to go ahead and show the loading notification while fetching our data
		        continueTooltip();

		        // next, we want to check if our data has already been cached
		        if (origin.data('ajax') !== 'cached') {
		            $.ajax({
		                type: 'GET',
		                url: url,
		                success: function(data) {
		                    // update our tooltip content with our returned data and cache it
		                    origin.tooltipster('content', data).data('ajax', 'cached');
		                }
		            });
		        }
		    }
		});
	},

	insertImage: function() {
		var filename = $('#sanitizedFilename').text();

		if (filename !== '') {
			var params = '';

			var modal = this.$imgModal;
			var $imgParamWidth = modal.find('#imgParamWidth');
			var $imgParamWidthUnits = modal.find('#imgParamWidthUnits');
			var $imgParamHeight = modal.find('#imgParamHeight');
			var $imgParamHeightUnits = modal.find('#imgParamHeightUnits');
			var $imgParamAngle = modal.find('#imgParamAngle');
			var $imgParamOrigin = modal.find('#imgParamOrigin');
			var $enableFigureCheckbox = modal.find('#enableImageFigure');
			var $figureParams = modal.find('#figureParams');
			var $figureCaption = modal.find('#figureCaption');
			var $figureLabel = modal.find('#figureLabel');

			if ($imgParamWidth.val() !== '') {
				params += 'width=' + $imgParamWidth.val() + $imgParamWidthUnits.val() + ',';
			}

			if ($imgParamHeight.val() !== '') {
				params += 'height=' + $imgParamHeight.val() + $imgParamHeightUnits.val() + ',';
			}

			if ($imgParamAngle.val() !== '') {
				params += 'angle=' + $imgParamAngle.val() + ',';
			}

			if ($imgParamOrigin.val() !== '') {
				params += 'origin=' + $imgParamOrigin.val() + ',';
			}

			if ($enableFigureCheckbox.is(':checked')) {
				var figureParams = '';
				var figureOthers = '';

				if ($figureParams.val() !== '') {
					figureParams += '[' + $figureParams.val() + ']';
				}

				if ($figureCaption.val() !== '') {
					figureOthers += '\n\\caption{' + $figureCaption.val() + '}';
				}

				if ($figureLabel.val() !== '') {
					figureOthers += '\n\\label{' + $figureLabel.val() + '}';
				}
				editor.insert('\n\\begin{figure}' + figureParams);
				editor.insert('\n\\includegraphics[' + params + ']{' + filename + '}' + figureOthers);
				editor.insert('\n\\end{figure}\n');
			} else {
				editor.insert('\n\\includegraphics[' + params + ']{' + filename + '}');
			}

			editor.focus();
			modal.toggle('slide', {direction: 'up'}, 'fast');
			return;
		}

		alert('Vyberte prosím obrázek pro vložení.');
	},


	getTableModalHtml: function() {
		var dialog ='<div id="table_remove" class="skryte"></div><table id="table_E"><tbody><tr><td>'+TranslVar[327]+':</td><td>	<input id="startSL" type="text" style="width: 30px;" value="5" onkeypress="return OnlyNumber(event)" />     <input id="pocetSl" type="hidden"/></td></tr><tr><td>'+TranslVar[328]+':</td><td>	<input id="startRa" type="text" style="width: 30px;" value="5" onkeypress="return OnlyNumber(event)" />     <input id="pocetRa" type="hidden"/></td></tr><tr class="skryte"><td>'+TranslVar[445]+':</td><td><select id="table_prost"><option value="array" disabled>array</option><option value="tabular" selected>tabular</option><option value="tabular*" disabled>tabular*</option><option value="longtable" disabled>longtable</option></select></td></tr></tbody></table><input id="bunka" type="hidden" value="2_0"/><input id="bunka2" type="hidden" value="0_1"/><input id="bunka3" type="hidden" value="0_0"/><input id="bunka3s" type="hidden" value="true"/><div id="table_A" class="skryte"><input type="text" id="editbox" style="width: 100%;" value=""><div id="table_container" style="overflow: auto;height: 30%;"><table><tbody id="tabulka"></tbody></table></div><h3 id="table_switch" class="skryte">'+TranslVar[329]+'</h3><p id="table_switcher" class="skryte"><a href="javascript:table_insert(0)" title="'+TranslVar[330]+'"> <img src="./file/wysiwyg-tables-insert-col.gif" class="menu" alt="'+TranslVar[330]+'"/></a><a href="javascript:table_drop(0)" title="'+TranslVar[331]+'"><img src="./file/wysiwyg-tables-delete-col.gif" class="menu" alt="'+TranslVar[331]+'"/></a></p><p id="table_switcher2b"><a href="javascript:table_merge_cells(false)" title="'+TranslVar[438]+'"><img src="./file/wysiwyg-tables-merge-col.gif" class="menu" alt="'+TranslVar[438]+'"/></a> <a href="javascript:table_merge_cells(true)" title="'+TranslVar[439]+'"><img src="./file/wysiwyg-tables-mergew-col.gif" class="menu" alt="'+TranslVar[439]+'"/></a></p> <p id="table_switcher2c"><a href="javascript:table_unmerge_cells()" title="'+TranslVar[440]+'"><img src="./file/wysiwyg-tables-unmerge-col.gif" class="menu" alt="'+TranslVar[440]+'"/></a><img class="oddelovac" alt="|" src="file/o.png"/><a href="javascript:table_align(\'left\')" title="'+TranslVar[11]+'"><img id="table_a2l" alt="'+TranslVar[11]+'" class="menu" src="file/left.gif"/></a>  <a href="javascript:table_align(\'center\')" title="'+TranslVar[12]+'"><img id="table_a2c" alt="'+TranslVar[12]+'" class="menu" src="file/center.gif"></a> <a href="javascript:table_align(\'right\')" title="'+TranslVar[13]+'"><img id="table_a2r" alt="'+TranslVar[13]+'" class="menu" src="file/right.gif"></a></p><p id="table_switcher2" class="skryte"><a href="javascript:table_insert(1)" title="'+TranslVar[332]+'"> <img src="./file/wysiwyg-tables-insert-row.gif" class="menu" alt="'+TranslVar[332]+'"/></a><a href="javascript:table_drop(1)" title="'+TranslVar[333]+'"><img src="./file/wysiwyg-tables-delete-row.gif" class="menu" alt="'+TranslVar[333]+'"/></a></p><div id="table_switcher5" class="skryte"><img class="oddelovac" alt="|" src="file/o.png"/><a href="javascript:table_set_align(\'left\')" title="'+TranslVar[11]+'"><img id="table_al" alt="'+TranslVar[11]+'" class="menu" src="file/left.gif"/></a>  <a href="javascript:table_set_align(\'center\')" title="'+TranslVar[12]+'"><img id="table_ac" alt="'+TranslVar[12]+'" class="menu" src="file/center.gif"></a> <a href="javascript:table_set_align(\'right\')" title="'+TranslVar[13]+'"><img id="table_ar" alt="'+TranslVar[13]+'" class="menu" src="file/right.gif"></a> <a href="javascript:table_set_align(\'justify\');" title="'+TranslVar[334]+'"><img id="table_aj" alt="'+TranslVar[334]+'" class="menu" src="file/justify.gif"></a><div id="tabular_men_justify" class="skryte"><h2>'+TranslVar[335]+'</h2> <table style="overflow: visible; opacity: 1; display: block;"><tr><td><input id="tabular_justify" type="text" onchange="OnlyNumberDotLast(this);table_set_align(\'justify\');" value="2" onkeypress="return OnlyNumberDot(event,$(this).val())"></td><td>'+jednotky("tabular_jed_justify","table_set_align(\'justify\');")+'</td></tr></table></div></div>';
		dialog+='<h3 id="table_switcherM" class="skryte">'+TranslVar[336]+'</h3><div id="table_switcherN" class="skryte"><div><a href="javascript:table_set_border(0)"title="'+TranslVar[337]+'"><img src="./file/wysiwyg-tables-borders-none.gif" class="menu" alt="'+TranslVar[337]+'"/></a> <a href="javascript:table_set_border(1)" id="table_switcher3c" class="skryte" title="'+TranslVar[338]+'"><img src="./file/wysiwyg-tables-borders-outer-only.gif" class="menu" alt="'+TranslVar[338]+'"/></a>';
		dialog +='<a href="javascript:table_set_border(\'top\');" title="'+TranslVar[339]+'"><img src="./file/wysiwyg-tables-borders-top.gif" class="menu" alt="'+TranslVar[339]+'"/></a> <a href="javascript:table_set_border(\'bottom\')" title="'+TranslVar[340]+'"> <img src="./file/wysiwyg-tables-borders-bottom.gif" class="menu" alt="'+TranslVar[340]+'"/></a> <a href="javascript:table_set_border(\'line\')" style="display:inline" title="'+TranslVar[341]+'"><img src="./file/wysiwyg-tables-borders-line.gif" class="menu" alt="'+TranslVar[341]+'"/></a> <a href="javascript:table_set_border(\'line_inside\')" id="table_switcher3aa" class="skryte" title="'+TranslVar[342]+'"><img src="./file/wysiwyg-tables-borders-line-inside.gif" class="menu" alt="'+TranslVar[342]+'"/></a>';
		dialog +='<div id="table_switcher3" class="skryte"><a href="javascript:table_set_border(\'left\');" title="'+TranslVar[343]+'"><img src="./file/wysiwyg-tables-borders-left.gif" class="menu" alt="'+TranslVar[343]+'"/></a> <a href="javascript:table_set_border(\'right\')" title="'+TranslVar[344]+'"><img src="./file/wysiwyg-tables-borders-right.gif" class="menu" alt="'+TranslVar[344]+'"/></a> <a href="javascript:table_set_border(\'columns\')" title="'+TranslVar[345]+'"><img src="./file/wysiwyg-tables-borders-vertical.gif" class="menu" alt="'+TranslVar[345]+'"/></a></div>';
		dialog +='<a href="javascript:table_set_border(\'columns_inside\')" id="table_switcher3ab" class="skryte" title="'+TranslVar[346]+'"><img src="./file/wysiwyg-tables-borders-columns-inside.gif" class="menu" alt="'+TranslVar[346]+'"/></a><a href="javascript:table_set_border(2)" id="table_switcher3a" class="skryte" title="'+TranslVar[347]+'"><img src="./file/wysiwyg-tables-borders-outer-with.gif" class="menu" alt="'+TranslVar[347]+'"/></a> <a href="javascript:table_set_border(3)" id="table_switcher3b" class="skryte" title="'+TranslVar[348]+'"><img src="./file/wysiwyg-tables-borders-outer-all.gif" class="menu" alt="'+TranslVar[348]+'"/></a>  <a id="tabular_ohranic_p_zmena" href="javascript:;" onclick="$(\'#table_ohraniceni\').show();$(this).hide();$(\'#tabular_ohranic_p2\').show()" class=\"skryte\">&raquo;&nbsp;'+TranslVar[24]+'</a><a id="tabular_ohranic_p2" href="javascript:;" class="skryte" onclick="$(\'#table_ohraniceni\').hide();$(this).hide();$(\'#tabular_ohranic_p\').show()">&raquo;&nbsp;'+TranslVar[364]+'</a></div><br /><p>'+TranslVar[349]+': <select id="table_line"><option value="none" title="'+TranslVar[350]+'">&nbsp;</option><option value="solid" title="'+TranslVar[351]+'" selected>-</option><option value="double" title="'+TranslVar[352]+'">=</option></select></p></div><div id="table_ohraniceni" class="skryte"><table width="130px"><tr><td id="ohranic_lefttop" width="15px" style="cursor:pointer;background:white;border-color:blue;border-right-style:solid;border-bottom-style:solid" onclick="table_ohranic(\'lefttop\')">&nbsp;&nbsp;</td><td id="ohranic_top" width="100px" style="cursor:pointer;background:white" onclick="table_ohranic(\'top\')">&nbsp;&nbsp;</td><td id="ohranic_topright" width="15px" style="cursor:pointer;background:white;border-color:blue;border-left-style:solid;border-bottom-style:solid" onclick="table_ohranic(\'topright\')">&nbsp;&nbsp;</td></tr><tr><td id="ohranic_left" style="cursor:pointer;background:white" onclick="table_ohranic(\'left\')">&nbsp;&nbsp;</td><td id="ohranic_center" height="25px">&nbsp;&nbsp;</td><td id="ohranic_right" style="cursor:pointer;background:white" onclick="table_ohranic(\'right\')">&nbsp;&nbsp;</td></tr><tr><td id="ohranic_leftbottom" style="cursor:pointer;background:white;border-color:blue;border-right-style:solid;border-top-style:solid" onclick="table_ohranic(\'leftbottom\')">&nbsp;&nbsp;</td><td id="ohranic_bottom" style="cursor:pointer;background:white" onclick="table_ohranic(\'bottom\')">&nbsp;&nbsp;</td><td id="ohranic_bottomright" style="cursor:pointer;background:white;border-color:blue;border-left-style:solid;border-top-style:solid" onclick="table_ohranic(\'bottomright\')">&nbsp;&nbsp;</td></tr></table></div>';
		//podbarveni bunek
		dialog+='<div id="colormixer_"><h3>'+TranslVar[474]+'</h3><table id="colormixer"><tr><td class="white">white</td><td class="yellow">yellow</td><td class="fuchsia">fuchsia</td><td class="aqua">aqua</td><td class="red">red</td><td class="lime">lime</td><td class="blue">blue</td><td class="black">black</td></tr>';
		dialog+='<tr><td class="green">green</td><td class="maroon">maroon</td><td class="olive">olive</td><td class="purple">purple</td><td class="gray">gray</td><td class="navy">navy</td><td class="teal">teal</td><td class="silver">silver</td></tr>';
		dialog+='</table>';
		//dialog+="<a href=\"javascript:tablemcolor()\" >"+TranslVar[477]+"&nbsp;>>&nbsp;</a>";
		dialog+="<p id=\"colorpickerHolder\"></p>";
		dialog+='</div>';
		// plovouci prostredi, nahled apod.
		dialog+='<h3>'+TranslVar[353]+'</h3><p id="tabular_ptable2"><input id="tabular_ptable" type="checkbox" onclick="tabular_ptable()"/>'+TranslVar[446]+'</p><p><input class="button modal-button gray-button" type="button" onclick="prepni_nahled()" value="'+TranslVar[354]+'"/></p><p><textarea id="tabular_nahled" class="skryte" rows="10" cols="30" readonly style="background-color:white"></textarea></p><div id="tabular_nahled_baliky" class="skryte"><h2>'+TranslVar[356]+'</h2><select id="tabular_nahled_baliky_val"><option> </option></select></div></div>';
		return dialog;
	}

};

$(function() {
	TOW.ToolsPanel.init();
	$('.tools-item').tooltipster();
	$('.modal-icon').tooltipster();
});

// fce se zavola kdyz je obrazek nahran
function imageUploaded(file) {
	var path = "";
	if(isVersion)
		vlozSouborSVN(filename, path);
	 // Skryti nahravaci zpravy
	 setTimeout(function () {
		$('.flash-message').addClass("hidden");
	 	$(".flash-message").html("");
		$("#"+file).remove();
     	$("#imageUploadForm input[name=filename]").val("");
	 }, 500);
}

function jednotky(nazev,onchange) {
	if (nazev == "tabular_jed_justify"){
		var dalsi ="";
	} else {
		dalsi = "<option value=\"bp\">bp</option><option value=\"dd\">dd</option><option value=\"cc\">cc</option><option value=\"sp\">sp</option>";
	}
	return "<select id=\""+nazev+"\" title=\""+TranslVar[318]+"\" onchange=\""+onchange+"\"><option value=\"in\">in</option><option value=\"mm\">mm</option><option value=\"cm\">cm</option><option value=\"pt\">pt</option><option selected value=\"em\">em</option><option value=\"ex\">ex</option><option value=\"pc\">pc</option>"+dalsi+"</select>";
}
